You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by se...@apache.org on 2010/10/04 22:04:42 UTC

svn commit: r1004382 - in /directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap: message/ name/ schema/

Author: seelmann
Date: Mon Oct  4 20:04:42 2010
New Revision: 1004382

URL: http://svn.apache.org/viewvc?rev=1004382&view=rev
Log:
Fix checkstyle errors: HiddenField and Javadoc

Modified:
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/BindRequestImpl.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/CompareRequestImpl.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/ExtendedRequestImpl.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/LdapResultImpl.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/MessageDecoder.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/SearchRequestImpl.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/name/RDN.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/schema/AttributeTypeOptions.java

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/BindRequestImpl.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/BindRequestImpl.java?rev=1004382&r1=1004381&r2=1004382&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/MessageDecoder.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/MessageDecoder.java Mon Oct  4 20:04:42 2010
@@ -82,15 +82,15 @@ public final class MessageDecoder implem
         this.decoder = this.provider.getDecoder( binaryAttributeDetector, maxPDUSize );
         this.decoder.setCallback( new DecoderCallback()
         {
-            public void decodeOccurred( StatefulDecoder decoder, Object decoded )
+            public void decodeOccurred( StatefulDecoder statefulDecoder, Object decoded )
             {
                 if ( decoded instanceof Asn1Object )
                 {
-                    cb.decodeOccurred( decoder, LdapTransformer.transform( decoded ) );
+                    cb.decodeOccurred( statefulDecoder, LdapTransformer.transform( decoded ) );
                 }
                 else
                 {
-                    cb.decodeOccurred( decoder, decoded );
+                    cb.decodeOccurred( statefulDecoder, decoded );
                 }
             }
         } );
@@ -174,11 +174,11 @@ public final class MessageDecoder implem
     /**
      * Sets the callback used to deliver completly decoded PDU's.
      * 
-     * @param cb the callback to use for decoded PDU delivery
+     * @param callback the callback to use for decoded PDU delivery
      */
-    public void setCallback( DecoderCallback cb )
+    public void setCallback( DecoderCallback callback )
     {
-        this.cb = cb;
+        this.cb = callback;
     }
 
 

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/SearchRequestImpl.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/SearchRequestImpl.java?rev=1004382&r1=1004381&r2=1004382&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/SearchRequestImpl.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/SearchRequestImpl.java Mon Oct  4 20:04:42 2010
@@ -819,9 +819,9 @@ public class SearchRequestImpl extends A
     /**
      * {@inheritDoc}
      */
-    public void addAttributes( String... attributes )
+    public void addAttributes( String... attributesToAdd )
     {
-        for ( String attribute : attributes )
+        for ( String attribute : attributesToAdd )
         {
             this.attributes.add( attribute );
         }
@@ -1039,6 +1039,7 @@ public class SearchRequestImpl extends A
 
     /**
      * Return a string the represent a SearchRequest
+     * {@inheritDoc}
      */
     public String toString()
     {

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/name/RDN.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/name/RDN.java?rev=1004382&r1=1004381&r2=1004382&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/name/RDN.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/name/RDN.java Mon Oct  4 20:04:42 2010
@@ -224,9 +224,9 @@ public class RDN implements Cloneable, C
     /**
      * A constructor that parse a String representing a RDN.
      *
-     * @param rdn The String containing the RDN to parse
+     * @param rdn the String containing the RDN to parse
      * @param schemaManager the schema manager
-     * @throws LdapInvalidDnException If the RDN is invalid
+     * @throws LdapInvalidDnException if the RDN is invalid
      */
     public RDN( String rdn, SchemaManager schemaManager ) throws LdapInvalidDnException
     {
@@ -267,8 +267,8 @@ public class RDN implements Cloneable, C
     /**
      * A constructor that parse a String representing a RDN.
      *
-     * @param rdn The String containing the RDN to parse
-     * @throws LdapInvalidDnException
+     * @param rdn the String containing the RDN to parse
+     * @throws LdapInvalidDnException if the RDN is invalid
      */
     public RDN( String rdn ) throws LdapInvalidDnException
     {
@@ -278,16 +278,16 @@ public class RDN implements Cloneable, C
 
     /**
      * A constructor that constructs a RDN from a type and a value. Constructs
-     * an Rdn from the given attribute type and value. The string attribute
-     * values are not interpreted as RFC 2253 formatted RDN strings. That is,
+     * an RDN from the given attribute type and value. The string attribute
+     * values are not interpreted as RFC 4514 formatted RDN strings. That is,
      * the values are used literally (not parsed) and assumed to be un-escaped.
      *
-     * @param upType The user provided type of the RDN
-     * @param upValue The user provided value of the RDN
-     * @param normType The normalized provided type of the RDN
-     * @param normValue The normalized provided value of the RDN
+     * @param upType the user provided type of the RDN
+     * @param upValue the user provided value of the RDN
+     * @param normType the normalized provided type of the RDN
+     * @param normValue the normalized provided value of the RDN
      * @param schemaManager the schema manager
-     * @throws LdapInvalidDnException If the RDN is invalid
+     * @throws LdapInvalidDnException if the RDN is invalid
      */
     public RDN( String upType, String normType, String upValue, String normValue, SchemaManager schemaManager ) throws LdapInvalidDnException
     {
@@ -315,6 +315,13 @@ public class RDN implements Cloneable, C
 
 
     /**
+     * A constructor that constructs a RDN from a type and a value.
+     *
+     * @param upType the user provided type of the RDN
+     * @param upValue the user provided value of the RDN
+     * @param normType the normalized provided type of the RDN
+     * @param normValue the normalized provided value of the RDN
+     * @throws LdapInvalidDnException if the RDN is invalid
      * @see #RDN(String, String, String, String, SchemaManager)
      */
     public RDN( String upType, String normType, String upValue, String normValue ) throws LdapInvalidDnException
@@ -325,14 +332,14 @@ public class RDN implements Cloneable, C
 
     /**
      * A constructor that constructs a RDN from a type and a value. Constructs
-     * an Rdn from the given attribute type and value. The string attribute
-     * values are not interpreted as RFC 2253 formatted RDN strings. That is,
+     * an RDN from the given attribute type and value. The string attribute
+     * values are not interpreted as RFC 414 formatted RDN strings. That is,
      * the values are used literally (not parsed) and assumed to be un-escaped.
      *
-     * @param upType The user provided type of the RDN
-     * @param upValue The user provided value of the RDN
+     * @param upType the user provided type of the RDN
+     * @param upValue the user provided value of the RDN
      * @param schemaManager the schema manager
-     * @throws LdapInvalidDnException If the RDN is invalid
+     * @throws LdapInvalidDnException if the RDN is invalid
      */
     public RDN( String upType, String upValue, SchemaManager schemaManager ) throws LdapInvalidDnException
     {
@@ -360,6 +367,11 @@ public class RDN implements Cloneable, C
 
 
     /**
+     * A constructor that constructs a RDN from a type and a value. 
+     *
+     * @param upType the user provided type of the RDN
+     * @param upValue the user provided value of the RDN
+     * @throws LdapInvalidDnException if the RDN is invalid
      * @see #RDN(String, String, SchemaManager)
      */
     public RDN( String upType, String upValue ) throws LdapInvalidDnException
@@ -371,9 +383,9 @@ public class RDN implements Cloneable, C
     /**
      * A constructor that constructs a RDN from a type, a position and a length.
      *
-     * @param start The starting point for this RDN in the user provided DN
-     * @param length The RDN's length
-     * @param upName The user provided name
+     * @param start the starting point for this RDN in the user provided DN
+     * @param length the RDN's length
+     * @param upName the user provided name
      * @param normName the normalized name
      */
     RDN( int start, int length, String upName, String normName )
@@ -488,15 +500,16 @@ public class RDN implements Cloneable, C
      * Transform a RDN by changing the value to its OID counterpart and
      * normalizing the value accordingly to its type.
      *
-     * @param schemaManager The SchemaManager
-     * @throws LdapException If the RDN is invalid.
+     * @param sm the SchemaManager
+     * @return this RDN, normalized
+     * @throws LdapInvalidDnException if the RDN is invalid
      */
-    public RDN normalize( SchemaManager schemaManager ) throws LdapInvalidDnException
+    public RDN normalize( SchemaManager sm ) throws LdapInvalidDnException
     {
-        String upName = getName();
-        DN.rdnOidToName( this, schemaManager.getNormalizerMapping() );
+        String savedUpName = getName();
+        DN.rdnOidToName( this, sm.getNormalizerMapping() );
         normalize();
-        this.upName = upName;
+        this.upName = savedUpName;
         normalized = true;
 
         return this;
@@ -507,15 +520,16 @@ public class RDN implements Cloneable, C
      * Transform a RDN by changing the value to its OID counterpart and
      * normalizing the value accordingly to its type.
      *
-     * @param oidsMap The mapping between names and oids.
-     * @throws LdapException If the RDN is invalid.
+     * @param oidsMap the mapping between names and OIDs
+     * @return this RDN, normalized
+     * @throws LdapInvalidDnException if the RDN is invalid
      */
     public RDN normalize( Map<String, OidNormalizer> oidsMap ) throws LdapInvalidDnException
     {
-        String upName = getName();
+        String savedUpName = getName();
         DN.rdnOidToName( this, oidsMap );
         normalize();
-        this.upName = upName;
+        this.upName = savedUpName;
         normalized = true;
 
         return this;
@@ -668,9 +682,9 @@ public class RDN implements Cloneable, C
      * Get the Value of the AttributeTypeAndValue which type is given as an
      * argument.
      *
-     * @param type The type of the NameArgument
-     * @return The Value to be returned, or null if none found.
-     * @throws LdapInvalidDnException
+     * @param type the type of the NameArgument
+     * @return the Value to be returned, or null if none found.
+     * @throws LdapInvalidDnException if the RDN is invalid
      */
     public Object getValue( String type ) throws LdapInvalidDnException
     {
@@ -731,9 +745,9 @@ public class RDN implements Cloneable, C
 
 
     /**
-     * Get the Rdn length
+     * Get the RDN length
      *
-     * @return The Rdn length
+     * @return the RDN length
      */
     public int getLength()
     {
@@ -878,9 +892,9 @@ public class RDN implements Cloneable, C
      * <li>Order of ATAV is not important If the RDNs are not equals, a positive number is
      * returned if the first RDN is greater, negative otherwise
      *
-     * @param rdn
-     * @return 0 if both rdn are equals. -1 if the current RDN is inferior, 1 if
-     *         the current Rdn is superior, UNDEFINED otherwise.
+     * @param rdn the RDN to be compared
+     * @return 0 if both RDNs are equals. -1 if the current RDN is inferior, 1 if
+     *         the current RDN is superior, UNDEFINED otherwise.
      */
     public int compareTo( RDN rdn )
     {
@@ -1136,10 +1150,10 @@ public class RDN implements Cloneable, C
      *            The value to be unescaped
      * @return Returns a string value as a String, and a binary value as a byte
      *         array.
-     * @throws IllegalArgumentException -
+     * @throws IllegalArgumentException
      *             When an Illegal value is provided.
      */
-    public static Object unescapeValue( String value )
+    public static Object unescapeValue( String value ) throws IllegalArgumentException
     {
         if ( StringTools.isEmpty( value ) )
         {

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/schema/AttributeTypeOptions.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/schema/AttributeTypeOptions.java?rev=1004382&r1=1004381&r2=1004382&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/BindRequestImpl.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/BindRequestImpl.java Mon Oct  4 20:04:42 2010
@@ -130,12 +130,12 @@ public class BindRequestImpl extends Abs
      * Sets the authentication mechanism to simple or to SASL based
      * authentication.
      * 
-     * @param isSimple
+     * @param simple
      *            true if authentication is simple, false otherwise.
      */
-    public void setSimple( boolean isSimple )
+    public void setSimple( boolean simple )
     {
-        this.isSimple = isSimple;
+        this.isSimple = simple;
     }
 
 
@@ -206,12 +206,12 @@ public class BindRequestImpl extends Abs
     /**
      * Sets the mechanism associated with a SASL authentication
      * 
      * @param mechanism
      *            the mechanism otherwise
      */
-    public void setSaslMechanism( String mechanism )
+    public void setSaslMechanism( String saslMechanism )
     {
-        this.mechanism = mechanism;
+        this.mechanism = saslMechanism;
     }
 
 
@@ -290,13 +290,13 @@ public class BindRequestImpl extends Abs
      * an type-safe enumeration type for a binary value. If an LDAPv4 comes out
      * then we shall convert the return type to a type safe enumeration.
      * 
-     * @param isVersion3
+     * @param version3
      *            if true the client will be exhibiting version 3 bind behavoir,
      *            if false is used version 2 behavoir will be exhibited.
      */
-    public void setVersion3( boolean isVersion3 )
+    public void setVersion3( boolean version3 )
     {
-        this.isVersion3 = isVersion3;
+        this.isVersion3 = version3;
     }
 
 
@@ -342,8 +342,9 @@ public class BindRequestImpl extends Abs
 
 
     /**
-     * @see Object#equals(Object)
+     * {@inheritDoc}
      */
+    @Override
     public boolean equals( Object obj )
     {
         if ( obj == this )
@@ -406,9 +407,9 @@ public class BindRequestImpl extends Abs
 
 
     /**
-     * @see Object#hashCode()
-     * @return the instance's hash code 
+     * {@inheritDoc}
      */
+    @Override
     public int hashCode()
     {
         int hash = 37;
@@ -206,12 +206,12 @@ public class BindRequestImpl extends Abs
      * Sets the mechanism associated with a SASL authentication
      * 
-     * @param mechanism
-     *            the mechanism otherwise
+     * @param saslMechanism
+     *            the SASL mechanism
      */

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/CompareRequestImpl.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/CompareRequestImpl.java?rev=1004382&r1=1004381&r2=1004382&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/CompareRequestImpl.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/CompareRequestImpl.java Mon Oct  4 20:04:42 2010
@@ -68,8 +68,6 @@ public class CompareRequestImpl extends 
     /**
      * Creates an CompareRequest implementation to compare a named entry with an
      * attribute value assertion pair.
-     * 
-     * @param id the sequence identifier of the CompareRequest message.
      */
     public CompareRequestImpl()
     {
@@ -131,24 +129,24 @@ public class CompareRequestImpl extends 
     /**
      * Sets the attribute value to use in the comparison.
      * 
-     * @param attrVal the attribute value used in comparison.
+     * @param value the attribute value used in comparison.
      */
-    public void setAssertionValue( String attrVal )
+    public void setAssertionValue( String value )
     {
-        this.attrVal = new StringValue( attrVal );
+        this.attrVal = new StringValue( value );
     }
 
 
     /**
      * Sets the attribute value to use in the comparison.
      * 
-     * @param attrVal the attribute value used in comparison.
+     * @param value the attribute value used in comparison.
      */
-    public void setAssertionValue( byte[] attrVal )
+    public void setAssertionValue( byte[] value )
     {
-        if ( attrVal != null )
+        if ( value != null )
         {
-            this.attrVal = new BinaryValue( attrVal );
+            this.attrVal = new BinaryValue( value );
         }
         else
         {
@@ -171,11 +169,11 @@ public class CompareRequestImpl extends 
     /**
      * Sets the attribute id used in the comparison.
      * 
      * @param attrId the attribute id used in comparison.
      */
-    public void setAttributeId( String attrId )
+    public void setAttributeId( String attributeId )
     {
-        this.attrId = attrId;
+        this.attrId = attributeId;
     }
 
 
@@ -171,11 +169,11 @@ public class CompareRequestImpl extends 
      * Sets the attribute id used in the comparison.
      * 
-     * @param attrId the attribute id used in comparison.
+     * @param attributeId the attribute id used in comparison.
      */

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/ExtendedRequestImpl.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/ExtendedRequestImpl.java?rev=1004382&r1=1004381&r2=1004382&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/ExtendedRequestImpl.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/ExtendedRequestImpl.java Mon Oct  4 20:04:42 2010
@@ -87,11 +87,11 @@ public class ExtendedRequestImpl extends
     /**
      * Sets the Object Identifier corresponding to the extended request type.
      * 
      * @param oid the dotted-decimal representation as a String of the OID
      */
-    public void setRequestName( String oid )
+    public void setRequestName( String newOid )
     {
-        this.oid = oid;
+        this.oid = newOid;
     }
 
 
@@ -259,6 +259,18 @@ public class ExtendedRequestImpl extends
     }
 
 
+    /**
+     * Creates the extended response.
+     * 
+     * This implement always returns null.
+     *
+     * @param id the OID
+     * @param berValue the value
+     * @param offset the offset
+     * @param length the length
+     * @return the extended response
+     * @throws NamingException the naming exception
+     */
     public ExtendedResponse createExtendedResponse( String id, byte[] berValue, int offset, int length )
         throws NamingException
     {
@@ -87,11 +87,11 @@ public class ExtendedRequestImpl extends
      * Sets the Object Identifier corresponding to the extended request type.
      * 
-     * @param oid the dotted-decimal representation as a String of the OID
+     * @param newOid the dotted-decimal representation as a String of the OID
      */

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/LdapResultImpl.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/LdapResultImpl.java?rev=1004382&r1=1004381&r2=1004382&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/LdapResultImpl.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/LdapResultImpl.java Mon Oct  4 20:04:42 2010
@@ -37,7 +37,7 @@ public class LdapResultImpl implements L
     private DN matchedDn;
 
     /** Temporary storage of the byte[] representing the matchedDN */
-    private byte[] matchedDNBytes;
+    private byte[] matchedDnBytes;
 
     /** Referral associated with this LdapResult if the errorCode is REFERRAL */
     private Referral referral;
@@ -123,7 +123,7 @@ public class LdapResultImpl implements L
      */
     /*No qualifier*/byte[] getMatchedDnBytes()
     {
-        return matchedDNBytes;
+        return matchedDnBytes;
     }
 
 
@@ -142,11 +142,11 @@ public class LdapResultImpl implements L
     /**
      * Sets the encoded value for MatchedDn
      * 
      * @param matchedDNBytes The encoded MatchedDN
      */
-    /*No qualifier*/void setMatchedDnBytes( byte[] matchedDNBytes )
+    /*No qualifier*/void setMatchedDnBytes( byte[] matchedDnBytes )
     {
-        this.matchedDNBytes = matchedDNBytes;
+        this.matchedDnBytes = matchedDnBytes;
     }
 
 
@@ -142,11 +142,11 @@ public class LdapResultImpl implements L
      * Sets the encoded value for MatchedDn
      * 
-     * @param matchedDNBytes The encoded MatchedDN
+     * @param matchedDnBytes The encoded MatchedDN
      */

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/MessageDecoder.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/message/MessageDecoder.java?rev=1004382&r1=1004381&r2=1004382&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/schema/AttributeTypeOptions.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/schema/AttributeTypeOptions.java Mon Oct  4 20:04:42 2010
@@ -39,11 +39,11 @@ public class AttributeTypeOptions
 {
     /** The attributeType */
     private AttributeType attributeType;
-    
+
     /** The options, if any */
     private Set<String> options;
-    
-    
+
+
     /**
      * Creates a new instance of AttributeTypeOptions, containing an attributeType, 
      * but no options.
@@ -68,8 +68,8 @@ public class AttributeTypeOptions
         this.attributeType = attributeType;
         this.options = options;
     }
-    
-    
+
+
     /**
      * @return the inner attributeType
      */
@@ -78,7 +78,7 @@ public class AttributeTypeOptions
         return attributeType;
     }
 
-    
+
     /**
      * @return the associated options
      */
@@ -86,8 +86,8 @@ public class AttributeTypeOptions
     {
         return options;
     }
-    
-    
+
+
     /**
      * @return <code>true</code> if the attributeType has at least one option
      */
@@ -95,8 +95,8 @@ public class AttributeTypeOptions
     {
         return ( options != null ) && ( options.size() != 0 );
     }
-    
-    
+
+
     /**
      * @param option the option to check
      * @return <code>true</code> if the attributeType has the given option
@@ -107,13 +107,13 @@ public class AttributeTypeOptions
         {
             return options.contains( StringTools.toLowerCase( StringTools.trim( option ) ) );
         }
-        else 
+        else
         {
             return false;
         }
     }
-    
-    
+
+
     /**
      * Add a new option to the option set for this attributeType.
      *
@@ -125,7 +125,7 @@ public class AttributeTypeOptions
         {
             options = new HashSet<String>();
         }
-        
+
         options.add( StringTools.toLowerCase( StringTools.trim( option ) ) );
     }
 
@@ -133,30 +133,33 @@ public class AttributeTypeOptions
     /**
      * Add a set of optionS to the option set for this attributeType.
      *
      * @param options the options to add
      */
-    public void addOptions( Set<String> options )
+    public void addOptions( Set<String> optionsToAdd )
     {
         if ( this.options == null )
         {
-            this.options = options;
+            this.options = optionsToAdd;
         }
         else
         {
-            this.options.addAll( options );
+            this.options.addAll( optionsToAdd );
         }
     }
-    
-    
+
+
+    /**
+     * {@inheritDoc}
+     */
     public String toString()
     {
         StringBuilder sb = new StringBuilder();
-        
+
         sb.append( "<" ).append( attributeType.getName() );
-        
+
         if ( hasOption() )
         {
-            for ( String option:options )
+            for ( String option : options )
             {
                 sb.append( ";" ).append( option );
             }
@@ -133,30 +133,33 @@ public class AttributeTypeOptions
      * Add a set of optionS to the option set for this attributeType.
      *
-     * @param options the options to add
+     * @param optionsToAdd the options to add
      */